/*
 * Copyright 2008-2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.derquinsej.tuple;

import static com.google.common.base.Preconditions.checkNotNull;

/**
 * Abstract implementation of array-based tuples.
 * @author Andres Rodriguez
 */
abstract class AbstractArrayTuple extends AbstractTuple {
	/** Elements. */
	private final Object[] array;
	/** Hash code. */
	private final int hash;

	/**
	 * Constructor.
	 * @param e Elements. No defensive copy is made.
	 */
	AbstractArrayTuple(Object... e) {
		this.array = checkNotNull(e);
		this.hash = super.hashCode();
	}
	
	/*
	 * (non-Javadoc)
	 * @see net.sf.derquinsej.tuple.Tuple#arity()
	 */
	public final int arity() {
		return array.length;
	}
	
	@Override
	public final int hashCode() {
		return hash;
	}
	
	/*
	 * (non-Javadoc)
	 * @see net.sf.derquinsej.tuple.Tuple#get(int)
	 */
	public Object get(int index) {
		checkIndex(index);
		return array[index];
	}
}
