/*
 * Copyright 2008-2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.derquinsej.tuple;

/**
 * Abstract implementation of a 2-element tuple.
 * @author Andres Rodriguez
 * @param <T1> First element type.
 * @param <T2> Second element type.
 * @param <T3> Third element type.
 */
abstract class AbstractTuple3<T1, T2, T3> extends AbstractArrayTuple implements Tuple3<T1, T2, T3> {
	/**
	 * Constructor.
	 * @param e Elements. No defensive copy is made.
	 */
	AbstractTuple3(Object... e) {
		super(e);
	}

	/*
	 * (non-Javadoc)
	 * @see net.sf.derquinsej.tuple.Tuple1#_1()
	 */
	@SuppressWarnings("unchecked")
	public T1 _1() {
		return (T1) get(0);
	}

	/*
	 * (non-Javadoc)
	 * @see net.sf.derquinsej.tuple.Tuple2#_2()
	 */
	@SuppressWarnings("unchecked")
	public T2 _2() {
		return (T2) get(1);
	}

	/*
	 * (non-Javadoc)
	 * @see net.sf.derquinsej.tuple.Tuple3#_3()
	 */
	@SuppressWarnings("unchecked")
	public T3 _3() {
		return (T3) get(2);
	}
}
