/*
 * Copyright 2008-2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.derquinsej.tuple;

import net.sf.derquinsej.HashBuilder;

/**
 * Empty tuple.
 * @author Andres Rodriguez
 */
final class Tuple0Impl extends AbstractTuple implements Tuple {
	static final Tuple0Impl TUPLE0 = new Tuple0Impl();
	/** Hash code. */
	private final int hash = new HashBuilder().hashCode();
	
	/**
	 * Constructor.
	 */
	private Tuple0Impl() {
	}
	
	/*
	 * (non-Javadoc)
	 * @see net.sf.derquinsej.tuple.Tuple#arity()
	 */
	public int arity() {
		return 0;
	}
	
	/*
	 * (non-Javadoc)
	 * @see net.sf.derquinsej.tuple.Tuple#get(int)
	 */
	public Object get(int index) {
		throw new IndexOutOfBoundsException("Empty tuple");
	}
	
	@Override
	public int hashCode() {
		return hash;
	}
	
	@Override
	public String toString() {
		return "()";
	}
}
