/*
 * Copyright 2008-2009 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package net.sf.derquinsej.tuple;

/**
 * Implementation of a 2-element tuple.
 * @author Andres Rodriguez
 * @param <T1> First element type.
 * @param <T2> Second element type.
 */
final class Tuple2Impl<T1, T2> extends AbstractTuple implements Tuple2<T1, T2> {
	/** First element. */
	private final T1 e1;
	/** Second element. */
	private final T2 e2;
	/** Hash code. */
	private final int hash;

	/**
	 * Constructor.
	 * @param e1 First element.
	 * @param e2 Second element.
	 */
	Tuple2Impl(T1 e1, T2 e2) {
		this.e1 = e1;
		this.e2 = e2;
		hash = super.hashCode();
	}

	/*
	 * (non-Javadoc)
	 * @see net.sf.derquinsej.tuple.Tuple#arity()
	 */
	public int arity() {
		return 2;
	}

	/*
	 * (non-Javadoc)
	 * @see net.sf.derquinsej.tuple.Tuple1#_1()
	 */
	public T1 _1() {
		return e1;
	}

	/*
	 * (non-Javadoc)
	 * @see net.sf.derquinsej.tuple.Tuple2#_2()
	 */
	public T2 _2() {
		return e2;
	}

	/*
	 * (non-Javadoc)
	 * @see net.sf.derquinsej.tuple.Tuple#get(int)
	 */
	public Object get(int index) {
		checkIndex(index);
		return (index == 0) ? _1() : _2();
	}

	@Override
	public int hashCode() {
		return hash;
	}

	@Override
	public boolean equals(Object obj) {
		return equals(obj, Tuple2.class);
	}

	@Override
	public String toString() {
		return String.format("(%s, %s)", e1);
	}
}
